package cn.com.qmth.examcloud.support.cache;

import cn.com.qmth.examcloud.support.cache.bean.AppCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.ExamRecordPropertyCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.PrivilegeRolesCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.SmsAssemblyCacheBean;
import cn.com.qmth.examcloud.support.cache.bean.SysPropertyCacheBean;
import cn.com.qmth.examcloud.web.cache.ObjectRedisCacheProcessor;

/**
 * 所有缓存对象从此类获取
 *
 * @author WANGWEI
 * @date 2019年5月9日
 * @Copyright (c) 2018-? http://qmth.com.cn All Rights Reserved.
 */
public class CacheHelper {

	/**
	 * 获取APP
	 *
	 * @author WANGWEI
	 * @param appId
	 * @return
	 */
	public static AppCacheBean getApp(Long appId) {
		return ObjectRedisCacheProcessor.get("$_APP:", new Object[]{appId}, AppCacheBean.class);
	}

	/**
	 * 获取系统属性<br>
	 *
	 * @author WANGWEI
	 * @param propKey
	 * @return
	 */
	public static SysPropertyCacheBean getSysProperty(String propKey) {
		return ObjectRedisCacheProcessor.get("$_SYS_PROP:", new Object[]{propKey},
				SysPropertyCacheBean.class, "EC-CORE-BASIC",
				"cn.com.qmth.examcloud.core.basic.service.cache.SystemPropertyCache");
	}

	/**
	 * 根据考试记录id获取考试信息<br>
	 *
	 * @author WANGWEI
	 * @param propKey
	 * @return
	 */
	public static ExamRecordPropertyCacheBean getExamRecordProperty(Long examRecordDataId) {
		return ObjectRedisCacheProcessor.get("OE_EXAM_RECORD_PROP:", new Object[]{examRecordDataId},
				ExamRecordPropertyCacheBean.class, "EC-CORE-OE-STUDENT",
				"cn.com.qmth.examcloud.core.oe.common.cache.ExamRecordPropertyCache");
	}

	/**
	 * 根据短信配置代码获取短信配置详情
	 * 
	 * @param smsAssemblyCode
	 *            短信配置代码
	 * @return
	 */
	public static SmsAssemblyCacheBean getSmsAssembly(String smsAssemblyCode) {
		return ObjectRedisCacheProcessor.get("SMS_ASSEMBLY_PROP:", new Object[]{smsAssemblyCode},
				SmsAssemblyCacheBean.class, "EC-CORE-BASIC",
				"cn.com.qmth.examcloud.core.basic.dao.cache.SmsAssemblyCache");
	}

	/**
	 * 获取权限关联的角色集合
	 *
	 * @author WANGWEI
	 * @param rootOrgId
	 * @param privilegeCode
	 * @return
	 */
	public static PrivilegeRolesCacheBean getPrivilegeRoles(Long rootOrgId, String privilegeCode) {
		return ObjectRedisCacheProcessor.get("$_PRIV_ROLES:",
				new Object[]{rootOrgId, privilegeCode}, PrivilegeRolesCacheBean.class,
				"EC-CORE-BASIC",
				"cn.com.qmth.examcloud.core.basic.service.cache.PrrivilegeRolesCache");
	}

}
